
Pylint User Manual
==================

Pylint is a tool that checks for errors in Python code, tries to enforce a
coding standard and looks for code smells. It can also look for certain type
errors, it can recommend suggestions about how particular blocks can be
refactored and can offer you details about the code's complexity.


.. toctree::
   :maxdepth: 2
   :titlesonly:

   intro
   tutorial

   user_guide/index.rst
   how_tos/index.rst
   technical_reference/index.rst
   development_guide/index.rst

   faq
   backlinks
   support
   whatsnew/index.rst
